Module: CLLI::Pattern

Included in:
CLLI, Cities::ClassMethods, EntityType::ClassMethods, LocationType::ClassMethods
Defined in:
lib/clli/pattern.rb

Overview

This module provides the various patterns used for parsing CLLI strings.

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Class Method Details

.included(o) ⇒ Object

When this modeule is included then extend the including class with the methods defined in ClassMethods.



8
9
10
# File 'lib/clli/pattern.rb', line 8

def self.included(o)
  o.extend(ClassMethods)
end